package androidlab.athiemann.exercise6;

import android.content.Context;
import android.media.AudioManager;
import android.os.Build;

import java.util.Date;

import androidlab.athiemann.exercise6.util.CallReceiver;


public class CallEventReceiver extends CallReceiver {
    private AudioManager audioManager;
    private boolean wasMuted;

    @Override
    protected void onIncomingCallReceived(Context ctx, String number, Date start)
    {
        wasMuted = false;
        audioManager = (AudioManager)ctx.getSystemService(Context.AUDIO_SERVICE);

        if (CalendarChecker.isBusyOn(new Date(), ctx)) {
            mute(ctx);
        }
    }

    @Override
    protected void onMissedCall(Context ctx, String number, Date start) {
        unmute(ctx);
    }


    private void mute(Context ctx) {
        if (audioManager != null) {
            if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M) {
                if (!audioManager.isStreamMute(AudioManager.STREAM_RING)) {
                    wasMuted = false;
                    audioManager.adjustStreamVolume(AudioManager.STREAM_RING, AudioManager.ADJUST_MUTE, 0);
                } else {
                    wasMuted = true;
                }
            } else {
                wasMuted = audioManager.isStreamMute(AudioManager.STREAM_RING);
                audioManager.setStreamMute(AudioManager.STREAM_RING, true);
            }
        }
    }

    private void unmute(Context ctx) {
        if (audioManager != null && wasMuted) {
            if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M) {
                audioManager.adjustStreamVolume(AudioManager.STREAM_RING, AudioManager.ADJUST_UNMUTE, 0);
            } else {
                audioManager.setStreamMute(AudioManager.STREAM_RING, false);
            }
        }
    }
}
